@@ -44,7 +44,7 @@ and L<FileHandle>.
 =cut
 
 
-our $VERSION = '0.12';
+our $VERSION = '0.13';
 
 use base qw(Anansi::Singleton);
 
@@ -64,28 +64,38 @@ my $ACTOR = Anansi::Actor->SUPER::new();
 
 =head2 DESTROY
 
-Declared in L<Anansi::Singleton>.  Deprecated.
+Declared in L<Anansi::Singleton>.
 
 =cut
 
 
 =head2 finalise
 
-Declared in L<Anansi::Class>.  Intended to be overridden by an extending module.
+    my $OBJECT = __PACKAGE__->Anansi::Singleton::new();
+    $OBJECT->finalise();
+
+    $Anansi::Actor::ACTOR->finalise();
+
+Declared as a virtual method in L<Anansi::Class>.
 
 =cut
 
 
 =head2 fixate
 
-Declared in L<Anansi::Singleton>.  Deprecated.
+    my $OBJECT = __PACKAGE__->Anansi::Singleton::new();
+    $OBJECT->fixate();
+
+    $Anansi::Actor::ACTOR->fixate();
+
+Declared as a virtual method in L<Anansi::Singleton>.
 
 =cut
 
 
 =head2 implicate
 
-Declared in L<Anansi::Class>.  Intended to be overridden by an extending module.
+Declared as a virtual method in L<Anansi::Class>.
 
 =cut
 
@@ -99,11 +109,108 @@ Declared in L<Anansi::Class>.
 
 =head2 initialise
 
-Declared in L<Anansi::Class>.  Intended to be overridden by an extending module.
+    my $OBJECT = __PACKAGE__->Anansi::Singleton::new();
+    $OBJECT->initialise();
+
+    $Anansi::Actor::ACTOR->initialise();
+
+Declared as a virtual method in L<Anansi::Class>.
 
 =cut
 
 
+=head2 new
+
+    my $object = Anansi::Actor->new(
+        PACKAGE => 'Anansi::Example',
+    );
+
+=over 4
+
+=item class I<(Blessed Hash B<or> String, Required)>
+
+Either an object or a string of this namespace.
+
+=item parameters I<(Hash)>
+
+Named parameters.
+
+=over 4
+
+=item BLESS I<(String, Optional)>
+
+The name of the subroutine within the namespace that creates a blessed object of
+the namespace.  Defaults to I<"new">.
+
+=item IMPORT I<(Array, Optional)>
+
+An array of the names to import from the loading module.
+
+=item PACKAGE I<(String, Required)>
+
+The namespace of the module to load.
+
+=item PARAMETERS I<(Array B<or> Hash, Optional)>
+
+Either An array or a hash of the parameters to pass to the blessing subroutine.
+
+=back
+
+=back
+
+Declared in L<Anansi::Singleton>.  Overridden by this module.  Instantiates an
+object instance of a dynamically loaded module.
+
+=cut
+
+
+sub new {
+    my ($class, %parameters) = @_;
+    return if(!defined($parameters{PACKAGE}));
+    return if(ref($parameters{PACKAGE}) !~ /^$/);
+    return if($parameters{PACKAGE} !~ /^[a-zA-Z]+[a-zA-Z0-9_]*(::[a-zA-Z]+[a-zA-Z0-9_]*)*$/);
+    if(!defined($parameters{BLESS})) {
+        $parameters{BLESS} = 'new';
+    } else {
+        return if(ref($parameters{BLESS}) !~ /^$/);
+        return if($parameters{BLESS} !~ /^[a-zA-Z]+[a-zA-Z0-9_]*$/);
+    }
+    if(defined($parameters{PARAMETERS})) {
+        $parameters{PARAMETERS} = [(%{$parameters{PARAMETERS}})] if(ref($parameters{PARAMETERS}) =~ /^HASH$/i);
+        return if(ref($parameters{PARAMETERS}) !~ /^ARRAY$/i);
+    }
+    if(defined($parameters{IMPORT})) {
+        return if(ref($parameters{IMPORT}) !~ /^ARRAY$/i);
+        foreach my $import (@{$parameters{IMPORT}}) {
+            return if(ref($import) !~ /^$/);
+            return if($import !~ /^[a-zA-Z_]+[a-zA-Z0-9_]*$/);
+        }
+    }
+    my $package = $parameters{PACKAGE};
+    my $bless = $parameters{BLESS};
+    my $self;
+    eval {
+        (my $file = $package) =~ s/::/\//g;
+        require $file.'.pm';
+        if(defined($parameters{IMPORT})) {
+            $package->import(@{$parameters{IMPORT}});
+        } else {
+            $package->import();
+        }
+        if(defined($parameters{PARAMETERS})) {
+            $self = $package->$bless(@{$parameters{PARAMETERS}});
+        } else {
+            $self = $package->$bless();
+        }
+        1;
+    } or do {
+        my $error = $@;
+        return ;
+    };
+    return $self;
+}
+
+
 =head2 old
 
 Declared in L<Anansi::Class>.
@@ -113,7 +220,12 @@ Declared in L<Anansi::Class>.
 
 =head2 reinitialise
 
-Declared in L<Anansi::Singleton>.  Deprecated.
+    my $OBJECT = __PACKAGE__->Anansi::Singleton::new();
+    $OBJECT->reinitialise();
+
+    $Anansi::Actor::ACTOR->reinitialise();
+
+Declared as a virtual method in L<Anansi::Singleton>.
 
 =cut
 
@@ -336,97 +448,6 @@ sub modules {
 }
 
 
-=head2 new
-
-    my $object = Anansi::Actor->new(
-        PACKAGE => 'Anansi::Example',
-    );
-
-=over 4
-
-=item class I<(Blessed Hash B<or> String, Required)>
-
-Either an object or a string of this namespace.
-
-=item parameters I<(Hash)>
-
-Named parameters.
-
-=over 4
-
-=item BLESS I<(String, Optional)>
-
-The name of the subroutine within the namespace that creates a blessed object of
-the namespace.  Defaults to I<"new">.
-
-=item IMPORT I<(Array, Optional)>
-
-An array of the names to import from the loading module.
-
-=item PACKAGE I<(String, Required)>
-
-The namespace of the module to load.
-
-=item PARAMETERS I<(Array B<or> Hash, Optional)>
-
-Either An array or a hash of the parameters to pass to the blessing subroutine.
-
-=back
-
-=back
-
-Instantiates an object instance of a dynamically loaded module.
-
-=cut
-
-
-sub new {
-    my ($class, %parameters) = @_;
-    return if(!defined($parameters{PACKAGE}));
-    return if(ref($parameters{PACKAGE}) !~ /^$/);
-    return if($parameters{PACKAGE} !~ /^[a-zA-Z]+[a-zA-Z0-9_]*(::[a-zA-Z]+[a-zA-Z0-9_]*)*$/);
-    if(!defined($parameters{BLESS})) {
-        $parameters{BLESS} = 'new';
-    } else {
-        return if(ref($parameters{BLESS}) !~ /^$/);
-        return if($parameters{BLESS} !~ /^[a-zA-Z]+[a-zA-Z0-9_]*$/);
-    }
-    if(defined($parameters{PARAMETERS})) {
-        $parameters{PARAMETERS} = [(%{$parameters{PARAMETERS}})] if(ref($parameters{PARAMETERS}) =~ /^HASH$/i);
-        return if(ref($parameters{PARAMETERS}) !~ /^ARRAY$/i);
-    }
-    if(defined($parameters{IMPORT})) {
-        return if(ref($parameters{IMPORT}) !~ /^ARRAY$/i);
-        foreach my $import (@{$parameters{IMPORT}}) {
-            return if(ref($import) !~ /^$/);
-            return if($import !~ /^[a-zA-Z_]+[a-zA-Z0-9_]*$/);
-        }
-    }
-    my $package = $parameters{PACKAGE};
-    my $bless = $parameters{BLESS};
-    my $self;
-    eval {
-        (my $file = $package) =~ s/::/\//g;
-        require $file.'.pm';
-        if(defined($parameters{IMPORT})) {
-            $package->import(@{$parameters{IMPORT}});
-        } else {
-            $package->import();
-        }
-        if(defined($parameters{PARAMETERS})) {
-            $self = $package->$bless(@{$parameters{PARAMETERS}});
-        } else {
-            $self = $package->$bless();
-        }
-        1;
-    } or do {
-        my $error = $@;
-        return ;
-    };
-    return $self;
-}
-
-
 =head1 NOTES
 
 This module is designed to make it simple, easy and quite fast to code your
